@@ -5,14 +5,24 @@
 # in http://www.gnu.org/licenses/gpl-3.0.html
 
 import os
+import subprocess
 import sys
 
 from Xlib import display
 from Xlib import X
 from Xlib import XK
+from Xlib.error import DisplayConnectionError
 from Xlib.ext import record
 from Xlib.protocol import rq
 
+def disable_access_control():
+    cmd = ['xhost', '+']
+    subprocess.Popen(cmd)
+
+try:
+    display.Display()
+except DisplayConnectionError as e:
+    disable_access_control()
 local_dpy = display.Display()
 record_dpy = display.Display()
 
